@@ -143,7 +143,12 @@ LOCAL int step_execute (const void *data, const void *user)
 		goto out;
 	}
 	
-	if (c->gen.manual) {
+	if (step->manual) {
+		if (!c->gen.manual)
+			LOG_MSG (LOG_WARNING, "Executing manual step from "
+				 "automatic case %s "
+				 "(generally not a good idea)",
+				 c->gen.name);
 		res = execute_manual (step);
 		goto out;
 	}
@@ -270,7 +275,7 @@ LOCAL int step_post_process (const void *data, const void *user)
 	td_case *c = (td_case *)user;
 
 	/* No post processing for manual steps ... */
-	if (c->gen.manual) 
+	if (step->manual) 
 		goto out;
 	/* ... or filtered ones ... */
 	if (c->filtered)
@@ -332,6 +337,11 @@ LOCAL int process_case (const void *data, const void *user)
 	if (c->gen.manual && opts.run_manual)
 		pre_manual (c);
 	cur_step_num = 0;
+	if (xmlListSize (c->steps) == 0) {
+		LOG_MSG (LOG_WARNING, "Case with no steps (%s).",
+			 c->gen.name);
+	}
+
 	xmlListWalk (c->steps, step_execute, data);
 	xmlListWalk (c->steps, step_post_process, data);
 	
